@@ -393,13 +393,14 @@ else                                     nui['nugget']=nuisance['nugget']
                               x1=1-(1-corr^2)*hr; x2=(1-hr)^2-(corr*hr)^2
                               y1=1-(1-corr^2)*hl; y2=(1-hl)^2-(corr*hl)^2
                               g=1-hl-hr+(1-corr^2)*hl*hr
-                              h1=sqrt(1-corr^2/(x1^2))+(corr/x1)*asin(corr/x1);h2=sqrt(1-corr^2/(y1^2))+(corr/y1)*asin(corr/y1)
+                              h1=sqrt(1-corr^2/(x1^2))+(corr/x1)*asin(corr/x1);
+                              h2=sqrt(1-corr^2/(y1^2))+(corr/y1)*asin(corr/y1)
+                              
                               h3=sqrt(1-corr^2/(x1*y1))+sqrt(corr^2/(x1*y1))*asin(sqrt(corr^2/(x1*y1)))
                               p1=x1*h1/(2*pi*(x2)^(3/2))+corr/(4*(x2)^(3/2)); p2=y1*h2/(2*pi*(y2)^(3/2))+corr/(4*(y2)^(3/2))
                               p3=-(x1*y1)^(1/2)*h3/(2*pi*(g)^(3/2))+corr/(4*(g)^(3/2))
                               mm=(hr-hl)/(sqrt(2*pi)*(1-hl)*(1-hr))
                               vs=0.5*((1-2*hl)^(-3/2)+(1-2*hr)^(-3/2)) -(mm)^2
-
                               cc=(p1+p2+2*p3-mm^2)/vs
                           covariance=sill*vs*cc;variogram=sill*vs*(1-cc)  
                              } 
