@@ -302,27 +302,27 @@ CVV_biv <- function(const,cova,ident,dimat,mdecomp,nuisance,setup,stdata)
 ################################################
         delta1=nuisance["tail1"]
         delta2=nuisance["tail2"]
-        if(stdata>0)
-        {
-        vv=sqrt(VGAM::lambertW(delta1*stdata^2)/delta1)
-        IL=sign(stdata)*vv
-        IW=1/(stdata*(1+VGAM::lambertW(delta1*stdata^2)))
-        llik <- 0.5*( const*log(sill)/log(2*pi) + 
-                      const + logdetvarcov + sum((backsolve(decompvarcov, IL, transpose = TRUE))^2)
-                      - 2*sum(log(IL*IW)))
-        }
-        if(stdata<=0){
-        vv=sqrt(VGAM::lambertW(delta2*stdata^2)/delta2)
-        IL=sign(stdata)*vv
-        IW=1/(stdata*(1+VGAM::lambertW(delta2*stdata^2)))
-        llik <- 0.5*( const*log(sill)/log(2*pi) + 
-                      const + logdetvarcov + sum((backsolve(decompvarcov, IL, transpose = TRUE))^2)
-                      - 2*sum(log(IL*IW)))
-        }
+a=which(stdata>=0); b=which(stdata<0)
+stmas=stdata[stdata>=0]; stmenos=stdata[stdata<0]
+
+g1<-(VGAM::lambertW(delta1*(stmas)^2)/(delta1))^(1/2)
+jac1<- g1/(stmas*(1+VGAM::lambertW(delta1*(stmas)^2)))
+
+g2<-(VGAM::lambertW(delta2*(stmenos)^2)/(delta2))^(1/2)
+jac2<- -g2/(stmenos*(1+VGAM::lambertW(delta2*(stmenos)^2)))
+
+pp=data.frame(rbind(cbind(a,g1),cbind(b,g2)))
+qq=data.frame(rbind(cbind(a,jac1),cbind(b,jac2)))
+
+g=pp[with(pp, order(pp$a)), ] 
+jac=qq[with(qq, order(qq$a)), ] 
+tau_inv=sign(stdata)*c(g$g1)
+
+llik <- 0.5*( const*log(sill)/log(2*pi) + 
+                      const + logdetvarcov + sum((backsolve(decompvarcov, c(tau_inv), transpose = TRUE))^2)- 2*sum(log(jac$jac1)))
         return(llik)
     }
 
-
 ######## Standard log-likelihood function for SH random fields
     LogNormDenStand_SH <- function(const,cova,ident,dimat,mdecomp,nuisance,sill,setup,stdata)
     {
@@ -447,7 +447,7 @@ CVV_biv <- function(const,cova,ident,dimat,mdecomp,nuisance,setup,stdata)
          corr= corr*(1-nuisance['nugget'])
         loglik_u <- do.call(what="LogNormDenStand_Tukey2H",
             args=list(stdata=((data-c(Mean))/(sqrt(sill))),const=const,cova=corr,dimat=dimat,ident=ident,
-            mdecomp=mdecomp,nuisance=nuisance,sill=(sill),setup=setup))
+            mdecomp=mdecomp,nuisance=nuisance,sill=sill,setup=setup))
         return(loglik_u)
       }
 ################################################################################################
